Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/makesrna/intern/rna_object.c')
-rw-r--r--source/blender/makesrna/intern/rna_object.c7
1 files changed, 3 insertions, 4 deletions
diff --git a/source/blender/makesrna/intern/rna_object.c b/source/blender/makesrna/intern/rna_object.c
index 33048d4b057..c2ee256ad58 100644
--- a/source/blender/makesrna/intern/rna_object.c
+++ b/source/blender/makesrna/intern/rna_object.c
@@ -1638,7 +1638,7 @@ bool rna_Object_modifiers_override_apply(Main *bmain,
return false;
}
/* While it would be nicer to use lower-level modifier_new() here, this one is lacking
* special-cases handling (particles and other physics modifiers mostly), so using the ED version
* instead, to avoid duplicating code. */
ModifierData *mod_dst = ED_object_modifier_add(
@@ -1653,7 +1653,7 @@ bool rna_Object_modifiers_override_apply(Main *bmain,
ParticleSystem *psys_dst = (mod_dst->type == eModifierType_ParticleSystem) ?
((ParticleSystemModifierData *)mod_dst)->psys :
NULL;
- modifier_copyData(mod_src, mod_dst);
+ BKE_modifier_copydata(mod_src, mod_dst);
if (mod_dst->type == eModifierType_ParticleSystem) {
psys_dst->flag &= ~PSYS_DELETE;
((ParticleSystemModifierData *)mod_dst)->psys = psys_dst;
@@ -1745,7 +1745,7 @@ bool rna_Object_greasepencil_modifiers_override_apply(Main *bmain,
return false;
}
/* While it would be nicer to use lower-level modifier_new() here, this one is lacking
* special-cases handling (particles and other physics modifiers mostly), so using the ED version
* instead, to avoid duplicating code. */
GpencilModifierData *mod_dst = ED_object_gpencil_modifier_add(
@@ -3204,7 +3204,6 @@ static void rna_def_object(BlenderRNA *brna)
prop = RNA_def_property(srna, "use_grease_pencil_lights", PROP_BOOLEAN, PROP_NONE);
RNA_def_property_boolean_sdna(prop, NULL, "dtx", OB_USE_GPENCIL_LIGHTS);
RNA_def_property_boolean_default(prop, true);
- RNA_def_property_clear_flag(prop, PROP_ANIMATABLE);
RNA_def_property_ui_text(prop, "Use Lights", "Lights affect grease pencil object");
RNA_def_property_update(prop, NC_OBJECT | ND_DRAW, "rna_GPencil_update");
@@ -1638,7 +1638,7 @@ bool rna_Object_modifiers_override_apply(Main *bmain,
return false;
}
- /* While it would be nicer to use lower-level modifier_new() here, this one is lacking
+ /* While it would be nicer to use lower-level BKE_modifier_new() here, this one is lacking
* special-cases handling (particles and other physics modifiers mostly), so using the ED version
* instead, to avoid duplicating code. */
@@ -1745,7 +1745,7 @@ bool rna_Object_greasepencil_modifiers_override_apply(Main *bmain,
return false;
}
- /* While it would be nicer to use lower-level modifier_new() here, this one is lacking
+ /* While it would be nicer to use lower-level BKE_modifier_new() here, this one is lacking
* special-cases handling (particles and other physics modifiers mostly), so using the ED version
* instead, to avoid duplicating code. */